@@ -1,4 +1,4 @@
-# ##########################   Qt_Сolored-logger   ########################### #
+# ##########################   Qt_Colored-logger   ########################### #
 # ---------------------------------------------------------------------------- #
 #                                                                              #
 # Copyright © 2023 Kalynovsky Valentin. All rights reserved.                   #
@@ -47,12 +47,12 @@ class HtmlColorSetInitQ:
 		HtmlColorSet['USER'] = HexColor('MEDIUMORCHID')
 		HtmlColorSet['STATUS'] = HexColor('ORANGE')
 		HtmlColorSet['STATUS_MESSAGE'] = HexColor('DARKORANGE')
-		HtmlColorSet['TYPE_DEBUG'] = HexColor('DIMGRAY')
-		HtmlColorSet['DEBUG_MESSAGE'] = HexColor('DARKGRAY')
-		HtmlColorSet['TYPE_DEBUG_PERFORMANCE'] = HexColor('SILVER')
-		HtmlColorSet['DEBUG_PERFORMANCE_MESSAGE'] = HexColor('GRAY')
-		HtmlColorSet['TYPE_PERFORMANCE'] = HexColor('GAINSBORO')
-		HtmlColorSet['PERFORMANCE_MESSAGE'] = HexColor('LIGHTGRAY')
+		HtmlColorSet['TYPE_DEBUG'] = HexColor('BURLYWOOD')
+		HtmlColorSet['DEBUG_MESSAGE'] = HexColor('TAN')
+		HtmlColorSet['TYPE_DEBUG_PERFORMANCE'] = HexColor('NAVAJOWHITE')
+		HtmlColorSet['DEBUG_PERFORMANCE_MESSAGE'] = HexColor('WHEAT')
+		HtmlColorSet['TYPE_PERFORMANCE'] = HexColor('BLANCHEDALMOND')
+		HtmlColorSet['PERFORMANCE_MESSAGE'] = HexColor('BISQUE')
 		HtmlColorSet['TYPE_EVENT'] = HexColor('MEDIUMSEAGREEN')
 		HtmlColorSet['EVENT_MESSAGE'] = HexColor('SEAGREEN')
 		HtmlColorSet['TYPE_AUDIT'] = HexColor('YELLOWGREEN')
@@ -122,7 +122,7 @@ class HtmlColorSetInitQ:
 		"""
 		from qt_colored_logger import ColorException
 		if color_name in HtmlColorSet:
-			HtmlColorSet[color_name] = f'#{hex(red)}{hex(green)}{hex(blue)}'
+			HtmlColorSet[color_name] = f'{"{:02x}".format(red)}{"{:02x}".format(green)}{"{:02x}".format(blue)}'
 		else:
 			raise ColorException("This color is not in the dictionary")
 
@@ -159,7 +159,7 @@ class LoggerQ:
 	"""
 	_instance = None
 
-	def __new__(cls):
+	def __new__(cls, *args, **kwargs):
 		if cls._instance is None:
 			cls._instance = super().__new__(cls)
 		return cls._instance
@@ -184,6 +184,7 @@ class LoggerQ:
 		:param status_type: setting the log type output
 		:param message: setting the log message output
 		"""
+		super().__init__()
 		self.time = time
 		self.name = name
 		self.status = status
@@ -580,7 +581,7 @@ class LoggerQ:
 		# log += f"</b>" if bold else ""
 		# return log
 		pass
-		# Должен выполняться в потоке
+		# Must run on a thread
 
 	def STOP_PROCESS(self, status_message_text: str = "", message_text: str = "", bold: bool = False, italic: bool = False) -> str:
 		"""
@@ -593,7 +594,7 @@ class LoggerQ:
 		:return: the generated log string
 		"""
 		pass
-		# Сделать переход в SUCCESS или FAIL
+		# Make transition to SUCCESS or FAIL
 
 	def SUCCESS(self, status_message_text: str = "", message_text: str = "", bold: bool = False, italic: bool = True) -> str:
 		"""
@@ -647,24 +648,33 @@ class LoggerQ:
 # Test
 if __name__ == "__main__":
 	mod = HtmlColorSetInitQ()
-	log = LoggerQ()
-	print(log.DEBUG("1", "2"))
-	print(log.DEBUG_PERFORMANCE("3", "4"))
-	print(log.PERFORMANCE("5", "6"))
-	print(log.EVENT("7", "8"))
-	print(log.AUDIT("9", "10"))
-	print(log.METRICS("11", "12"))
-	print(log.USER("13", "14"))
-	print(log.MESSAGE("15", "16"))
-	print(log.INFO("17", "18"))
-	print(log.NOTICE("19", "20"))
-	print(log.WARNING("21", "22"))
-	print(log.ERROR("23", "24"))
-	print(log.CRITICAL("25", "26"))
-	# print(log.START_PROCESS("27", "28"))
-	print(log.SUCCESS("29", "30"))
-	print(log.FAIL("31", "32"))
+	logger = LoggerQ(status_message=False)
+	print(logger.DEBUG("1", "2"))
+	print(logger.DEBUG_PERFORMANCE("3", "4"))
+	print(logger.PERFORMANCE("5", "6"))
+	print(logger.EVENT("7", "8"))
+	print(logger.AUDIT("9", "10"))
+	print(logger.METRICS("11", "12"))
+	print(logger.USER("13", "14"))
+	print(logger.MESSAGE("15", "16"))
+	print(logger.INFO("17", "18"))
+	print(logger.NOTICE("19", "20"))
+	print(logger.WARNING("21", "22"))
+	print(logger.ERROR("23", "24"))
+	print(logger.CRITICAL("25", "26"))
+	# print(logger.START_PROCESS("27", "28"))
+	print(logger.SUCCESS("29", "30"))
+	print(logger.FAIL("31", "32"))
 
-	print(len(HtmlColorSet))
-	mod.setColor("TIME", 100, 200, 255)
-	print(len(HtmlColorSet))
+	# print(len(HtmlColorSet))
+	# mod.setColor("TIME", 100, 200, 255)
+	# print(len(HtmlColorSet))
+
+	print(logger.DEBUG(message_text="Debug data"))
+	print(logger.DEBUG(message_text="Debug data", bold=True))
+	print(logger.DEBUG(message_text="Debug data", italic=True))
+	print(logger.DEBUG(message_text="Debug data", bold=True, italic=True))
+
+	print(logger.NOTICE(message_text="Debug data"))
+	mod.setColor("NOTICE_MESSAGE", 127, 255, 0)
+	print(logger.NOTICE(message_text="Debug data"))
